@@ -1,14 +1,14 @@
 /*
- * $Id: externalform.c,v 1.44 2004/01/05 17:31:57 nordstrom Exp $
+ * $Id: externalform.c,v 1.46 2004/04/19 15:43:45 prussar Exp $
  *
  * Viewer - a part of Plucker, the free off-line HTML viewer for PalmOS
  * Copyright (c) 1998-2002, Mark Ian Lillywhite and Michael Nordstrom
- * 
+ *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
  * as published by the Free Software Foundation; either version 2
  * of the License, or (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -32,6 +32,7 @@
 #include "uncompress.h"
 #include "util.h"
 #include "os.h"
+#include "DIA.h"
 
 #include "externalform.h"
 
@@ -250,12 +251,30 @@ Boolean ExternalLinksFormHandleEvent
             handled = true;
             break;
 
+		case winEnterEvent:
+			handled = ResizeHandleWinEnterEvent();
+			break;
+
+		case winDisplayChangedEvent:
+			handled = ResizeHandleWinDisplayChangedEvent();
+			break;
+
+		case winExitEvent:
+		    handled = ResizeHandleWinExitEvent();
+		    break;
+
         case frmOpenEvent:
+#ifdef HAVE_SILKSCREEN
+            ResizeHandleFrmOpenEvent();
+#endif
             ExternalLinksFormInit();
             handled = true;
             break;
 
         case frmCloseEvent:
+#ifdef HAVE_SILKSCREEN
+            ResizeHandleFrmCloseEvent();
+#endif
             handled = false;
             break;
 
