@@ -1,5 +1,5 @@
 /*
- * $Id: fontform.c,v 1.36 2004/02/01 11:26:33 nordstrom Exp $
+ * $Id: fontform.c,v 1.40 2004/04/29 01:52:05 prussar Exp $
  *
  * Viewer - a part of Plucker, the free off-line HTML viewer for PalmOS
  * Copyright (c) 1998-2002, Mark Ian Lillywhite and Michael Nordstrom
@@ -32,6 +32,7 @@
 #include "history.h"
 #include "grayfont.h"
 #include "metadocument.h"
+#include "mainform.h"
 
 #include "fontform.h"
 
@@ -340,8 +341,6 @@ static void FontFormInit( void )
         userFontButtonNumber   = 5;
     }
 
-    HanderaConvertForm( form );
-
     if ( cameFromLibrary ) {
         HideFontFormObject( frmFontLineSpacingLabel, false );
         HideFontFormObject( frmFontLineSpacingPopup, true );
@@ -541,8 +540,12 @@ void FontDoOK( void )
         }
 
         FrmReturnToForm( Prefs()->lastForm );
-        if ( updateDoc )
-            FrmUpdateForm( Prefs()->lastForm, frmRedrawUpdateCode );
+        if ( updateDoc ) {
+            if ( IsFormMain( Prefs()->lastForm ) )
+                SetMainFormUpdate();
+            else
+                FrmUpdateForm( Prefs()->lastForm, frmRedrawUpdateCode );
+        }
     }
 
     SafeMemPtrFree( buttonList );
@@ -676,12 +679,30 @@ Boolean FontFormHandleEvent
             }
             break;
 
+		case winEnterEvent:
+			handled = ResizeHandleWinEnterEvent();
+			break;
+
+		case winDisplayChangedEvent:
+			handled = ResizeHandleWinDisplayChangedEvent();
+			break;
+
+		case winExitEvent:
+		    handled = ResizeHandleWinExitEvent();
+		    break;
+
         case frmOpenEvent:
+#ifdef HAVE_SILKSCREEN
+            ResizeHandleFrmOpenEvent();
+#endif
             FontFormInit();
             handled = true;
             break;
 
         case frmCloseEvent:
+#ifdef HAVE_SILKSCREEN
+            ResizeHandleFrmCloseEvent();
+#endif
             SafeMemPtrFree( buttonList );
             break;
 
