@@ -1,14 +1,14 @@
 /*
- * $Id: fullscreenform.c,v 1.44 2004/03/07 11:17:25 nordstrom Exp $
+ * $Id: fullscreenform.c,v 1.47 2004/04/19 15:43:45 prussar Exp $
  *
  * Viewer - a part of Plucker, the free off-line HTML viewer for PalmOS
  * Copyright (c) 1998-2002, Mark Ian Lillywhite and Michael Nordstrom
- * 
+ *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
  * as published by the Free Software Foundation; either version 2
  * of the License, or (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -38,6 +38,7 @@
 #include "screen.h"
 #include "table.h"
 #include "util.h"
+#include "handera.h"
 
 #include "fullscreenform.h"
 
@@ -199,8 +200,8 @@ static Boolean FsFormInit( void )
         originalBackButtonWidth  = ctlBounds.extent.x;
         originalBackButtonHeight = ctlBounds.extent.y;
     }
-    ctlBounds.topLeft.x = 0;
-    ctlBounds.topLeft.y = RotMaxExtentY() - originalBackButtonHeight;
+    ctlBounds.topLeft.x = 1;
+    ctlBounds.topLeft.y = RotMaxExtentY() - originalBackButtonHeight - 1;
     ctlBounds.extent.x  = originalBackButtonWidth;
     ctlBounds.extent.y  = originalBackButtonHeight;
     
@@ -935,6 +936,7 @@ Boolean FsFormHandleEvent
             break;
 
         case winEnterEvent:
+			handled = ResizeHandleWinEnterEvent();
             if ( event->data.winEnter.enterWindow == (WinHandle) fsForm &&
                  event->data.winEnter.enterWindow ==
                                              (WinHandle) FrmGetFirstForm() )
@@ -944,16 +946,12 @@ Boolean FsFormHandleEvent
         case winExitEvent:
             if ( event->data.winExit.exitWindow == (WinHandle) fsForm )
                 menuActive = true;
+		    handled = ResizeHandleWinExitEvent();
             break;
 
-#ifdef HAVE_HANDERA_SDK
-        case displayExtentChangedEvent:
-            SilkHandleChange();
-            break;
-#endif
-
         case frmUpdateEvent:
             FreeMemory();
+			UpdateDisplayExtent();
             menuActive = false;
             if ( ! FsFormInit() ) {
                 /* Do something */
@@ -961,7 +959,14 @@ Boolean FsFormHandleEvent
             handled = true;
             break;
 
+		case winDisplayChangedEvent:
+			handled = ResizeHandleWinDisplayChangedEvent();
+			break;
+
         case frmOpenEvent:
+#ifdef HAVE_SILKSCREEN
+            ResizeHandleFrmOpenEvent();
+#endif
             menuActive = false;
             if ( ! FsFormInit() ) {
                 /* Do something */
@@ -971,6 +976,9 @@ Boolean FsFormHandleEvent
 
         case frmCloseEvent:
             FreeMemory();
+#ifdef HAVE_SILKSCREEN
+            ResizeHandleFrmCloseEvent();
+#endif
             handled = false;
             break;
 
