@@ -1,5 +1,5 @@
 /*
- * $Id: jogdial.c,v 1.21 2004/03/02 03:23:00 prussar Exp $
+ * $Id: jogdial.c,v 1.22 2004/04/21 15:10:18 prussar Exp $
  *
  * Viewer - a part of Plucker, the free off-line HTML viewer for PalmOS
  * Copyright (c) 1998-2002, Mark Ian Lillywhite and Michael Nordstrom
@@ -357,6 +357,9 @@ Boolean JogdialLibraryHandler
             jogRepeat = false;
             return LibrarySelectorHandler( librarySelectorPageDown, 0 );
         }
+        else if ( IsJogdialPush( chr ) ) {
+            handled = true;
+        }
         else {
             handled = false;
         }
