@@ -1,5 +1,5 @@
 /*
- * $Id: libraryform.c,v 1.97 2004/03/21 14:08:32 nordstrom Exp $
+ * $Id: libraryform.c,v 1.104 2004/04/30 01:08:42 prussar Exp $
  *
  * Viewer - a part of Plucker, the free off-line HTML viewer for PalmOS
  * Copyright (c) 1998-2002, Mark Ian Lillywhite and Michael Nordstrom
@@ -46,6 +46,7 @@
 #include "control.h"
 #include "keyboard.h"
 #include "grayfont.h"
+#include "DIA.h"
 
 #include "libraryform.h"
 
@@ -118,7 +119,7 @@ typedef struct {
  ***********************************************************************/
 static UInt16           libraryFormId = frmLibrary;
 static FormType*        libraryForm;
-static Char*            formTitle;
+static Char             formTitle[ MAX_TITLE_LENGTH ];
 static LinkedList       docList;
 static FontID           displayFont;
 static FontID           displayFontBold;
@@ -200,10 +201,7 @@ static void LibraryFormInit( void ) LIBRARYFORM_SECTION;
 static void DrawLayout( void ) LIBRARYFORM_SECTION;
 static void UpdateScrollbar(void) LIBRARYFORM_SECTION;
 static void DisplayCategoryStyle( void ) LIBRARYFORM_SECTION;
-static void ShowSyncMessage( void ) LIBRARYFORM_SECTION;
-static void HideSyncMessage( void ) LIBRARYFORM_SECTION;
 static void ShowSortMessage( void ) LIBRARYFORM_SECTION;
-static void HideSortMessage( void ) LIBRARYFORM_SECTION;
 static void UpdateSortMethod( void ) LIBRARYFORM_SECTION;
 static Int16 CompareTypeAsc( DocumentInfo* d1,
                 DocumentInfo* d2 ) LIBRARYFORM_SECTION;
@@ -275,11 +273,6 @@ void SetLibraryFormUpdate( void )
 /* Initialize the Document Library form */
 static void LibraryFormInit( void )
 {
-#ifdef HAVE_SILKSCREEN
-    if ( GetSilkScreenStatus() == SILKSCREEN_NONE )
-        SetSilkScreenStatus( SILKSCREEN_DOWN );
-#endif        
-
     if ( SetValidForm( &libraryFormId ) )
         return;
 
@@ -298,20 +291,9 @@ static void LibraryFormInit( void )
     CloseDocument();
 
     /* Move the library to the right, to make room for the help icon */
-    formTitle = SafeMemPtrNew( MAX_TITLE_LENGTH );
-    StrPrintF( formTitle, "      %s", FrmGetTitle( libraryForm ) );
-    FrmSetTitle( libraryForm, formTitle );
-    if ( ( IsHiResTypeSony( HiResType() ) ||
-           IsHiResTypePalm( HiResType() ) ) &&
-           SilkScreenType() != sonyV3SilkScreen &&
-           GetSilkScreenStatus() == SILKSCREEN_DOWN ) {
-        RectangleType sbBounds;
-        UInt16        sbIndex;
-
-        sbIndex = FrmGetObjectIndex( libraryForm, frmLibraryScrollBar );
-        FrmGetObjectBounds( libraryForm, sbIndex, &sbBounds );
-        sbBounds.extent.y += SILKSCREEN_HEIGHT_HIRES_SONY / 2;
-        FrmSetObjectBounds( libraryForm, sbIndex, &sbBounds );
+    if ( StrNCompare( FrmGetTitle( libraryForm ), "      ", 6 ) ) {
+        StrPrintF( formTitle, "      %s", FrmGetTitle( libraryForm ) );
+        FrmSetTitle( libraryForm, formTitle );
     }
 
     FrmDrawForm( libraryForm );
@@ -321,7 +303,7 @@ static void LibraryFormInit( void )
 
     DrawHelpIcon( libraryForm, frmLibraryHelp );
 
-    ShowSyncMessage();
+    ShowSyncMessage( POPUP );
 
     CalculateColumnWidths();
     InitializeDocInfoList();
@@ -329,7 +311,7 @@ static void LibraryFormInit( void )
     typeIconList = ListCreate();
     cardIconList = ListCreate();
 
-    HideSyncMessage();
+    HideMessage( POPUP );
 
     activateOnce    = true;
 
@@ -344,7 +326,6 @@ static void LibraryFormInit( void )
     ResetLookup();
 
     Prefs()->lastForm = libraryFormId;
-
     initializing = false;
 }
 
@@ -923,7 +904,7 @@ static void DrawLayout( void )
     UpdateSortMethod();
     ShowSortMessage();
     UpdateIndexList();
-    HideSortMessage();
+    HideMessage( POPUP );
     DrawRecords( 0, visibleRows );
 }
 
@@ -1205,54 +1186,35 @@ static void DisplayCategoryStyle( void )
 /* Display sorting message */
 static void ShowSortMessage( void )
 {
-    FormType* frm;
-
-    frm = FrmInitForm( frmSortDoc );
-
-    HanderaConvertForm( frm );
-    FrmSetActiveForm( frm );
-    FrmDrawForm( frm );
-}
-
-
-
-/* Hide sorting message */
-static void HideSortMessage( void )
-{
-    FormType* libraryForm;
-    FormType* frm;
-
-    libraryForm = FrmGetFormPtr( frmLibrary );
-    frm         = FrmGetFormPtr( frmSortDoc );
-
-    FrmEraseForm( frm );
-    FrmDeleteForm( frm );
-    FrmSetActiveForm( libraryForm );
+    FrmPopupForm( frmSortDoc );
 }
 
 
 
 /* Display Sync message */
-static void ShowSyncMessage( void )
+void ShowSyncMessage( Boolean popup )
 {
-    FormType* frm;
-
+    UInt16 formID;
     if ( Prefs()->syncPolicy == SYNC_MANUAL )
-        frm = FrmInitForm( frmOpenDocList );
+        formID = frmOpenDocList;
     else
-        frm = FrmInitForm( frmSyncDocList );
-
-    HanderaConvertForm( frm );
-    FrmSetActiveForm( frm );
-    FrmDrawForm( frm );
+        formID = frmSyncDocList;
+    if ( popup )
+        FrmPopupForm( formID );
+    else
+        FrmGotoForm( formID );
 }
 
 
 
 /* Hide Sync message */
-static void HideSyncMessage( void )
+void HideMessage( Boolean popup )
 {
-    FrmReturnToForm( libraryFormId );
+    EventType newEvent;
+
+    MemSet( &newEvent, sizeof( newEvent ), 0 );
+    newEvent.eType = popup ? pluckerClosePopupEvent : pluckerDeleteFormEvent;
+    EvtAddEventToQueue( &newEvent );
 }
 
 
@@ -1640,7 +1602,7 @@ static Boolean HandlePenOnSort
                 UpdateSortMethod();
                 ShowSortMessage();
                 UpdateIndexList();
-                HideSortMessage();
+                HideMessage( POPUP );
                 DrawRecords( 0, visibleRows );
             }
             handled = true;
@@ -2790,9 +2752,6 @@ void UpdateIndexList( void )
 
 static void ReleaseAllocatedMemory(void)
 {
-    SafeMemPtrFree( formTitle );
-    formTitle = NULL;
-
     SafeMemPtrFree(indexList);
     indexList = NULL;
 
@@ -2824,13 +2783,13 @@ void SyncDocList(void)
     syncPolicy = Prefs()->syncPolicy;
     Prefs()->syncPolicy = SYNC_AUTOMATIC;
 
-    ShowSyncMessage();
+    ShowSyncMessage( POPUP );
 
     CloseDocList();
     ReleaseDocInfoList();
     InitializeDocInfoList();
 
-    HideSyncMessage();
+    HideMessage( POPUP );
 
     Prefs()->syncPolicy = syncPolicy;
 
@@ -2845,7 +2804,7 @@ Boolean LibraryFormHandleEvent
 )
 {
     Boolean handled;
-    
+
     handled = false;
 
     switch ( event->eType ) {
@@ -2949,6 +2908,9 @@ Boolean LibraryFormHandleEvent
             break;
 
         case frmOpenEvent:
+#ifdef HAVE_SILKSCREEN
+            ResizeHandleFrmOpenEvent();
+#endif
 #ifdef HAVE_GRAY_FONT
             oldOrientation = GrayFntSetOrientation( GRAY_FONT_NORMAL );
 #endif
@@ -2956,10 +2918,18 @@ Boolean LibraryFormHandleEvent
             handled = true;
             break;
 
+		case winDisplayChangedEvent:
+			handled = ResizeHandleWinDisplayChangedEvent();
+			break;
+
+		case winExitEvent:
+		    handled = ResizeHandleWinExitEvent();
+		    break;
+
         case winEnterEvent:
+			handled = ResizeHandleWinEnterEvent();
             if ( forceLibraryFormUpdate ) {
                 forceLibraryFormUpdate = false;
-                FrmEraseForm( libraryForm );
                 FrmGotoForm( GetValidForm( libraryFormId ) );
             }
             handled = true;
@@ -2969,8 +2939,11 @@ Boolean LibraryFormHandleEvent
             switch ( event->data.frmUpdate.updateCode ) {
                 case frmRedrawUpdateCode:
                     if ( ! initializing ) {
-                        FrmEraseForm( libraryForm );
-                        FrmGotoForm( libraryFormId );
+#ifdef HAVE_SILKSCREEN
+                        ResizeHandleFrmRedrawUpdateCode();
+#endif
+                        ReleaseAllocatedMemory();
+                        LibraryFormInit();
                     }
                     handled = true;
                     break;
@@ -2980,7 +2953,7 @@ Boolean LibraryFormHandleEvent
                     InitializeDocInfoList();
                     ShowSortMessage();
                     UpdateIndexList();
-                    HideSortMessage();
+                    HideMessage( POPUP );
                     DrawRecords( 0, visibleRows );
                     handled = true;
                     break;
@@ -2994,9 +2967,10 @@ Boolean LibraryFormHandleEvent
             ReleaseAllocatedMemory();
             LoadUserFont( GetUserFontNumber( Prefs()->mainUserFontName,
                               true, fontCacheDoc ) );
-            if ( Prefs()->hideSonyStatusBar )
-                SetSilkScreenStatus( SILKSCREEN_NONE );
             RefreshCustomFonts();
+#ifdef HAVE_SILKSCREEN
+            ResizeHandleFrmCloseEvent();
+#endif
             handled = false;
             break;
 
@@ -3061,13 +3035,6 @@ Boolean LibraryFormHandleEvent
             }
             break;
 
-#ifdef HAVE_HANDERA_SDK
-        case displayExtentChangedEvent:
-            SilkHandleChange();
-            handled = true;
-            break;
-#endif
-
         default:
             handled = false;
             break;
