@@ -1,5 +1,5 @@
 /*
- * $Id: mainform.c,v 1.141 2004/02/17 01:27:26 chrish Exp $
+ * $Id: mainform.c,v 1.146 2004/04/30 01:08:42 prussar Exp $
  *
  * Viewer - a part of Plucker, the free off-line HTML viewer for PalmOS
  * Copyright (c) 1998-2002, Mark Ian Lillywhite and Michael Nordstrom
@@ -42,7 +42,7 @@
 #include "prefscontrol.h"
 #include "resourceids.h"
 #include "search.h"
-#include "silkscreen.h"
+#include "DIA.h"
 #include "util.h"
 #include "screen.h"
 #include "genericfile.h"
@@ -55,6 +55,7 @@
 #include "rotate.h"
 #include "dimensions.h"
 #include "metadocument.h"
+#include "handera.h"
 
 #include "mainform.h"
 
@@ -152,16 +153,9 @@ Boolean HandleCommonMenuItems
     handled = false;
     switch ( itemID ) {
         case mOptionsAbout:
-        {
-            FormType* form;
-
-            form = FrmInitForm( frmAbout );
-            HanderaConvertForm( form );
-            FrmDoDialog( form );
-            FrmDeleteForm( form );
+            FrmPopupForm( frmAbout );
             handled = true;
             break;
-        }
 
         case mOptionsContact:
             SetMailto( 0 );
@@ -346,7 +340,7 @@ void MainFormInit( void )
 
     ClearControlBounds();
     if ( Prefs()->toolbar == TOOLBAR_SILK ) {
-        SetSilkScreen();
+        HanderaSetSilkScreen();
     }
     else if ( Prefs()->toolbar != TOOLBAR_NONE ) {
         GetControlBounds( mainForm, bmpMenu, MENUCONTROL );
@@ -787,7 +781,7 @@ Boolean MainFormHandleEvent
 
             handled = true;
             break;
-            
+
 
 #ifdef SUPPORT_WORD_LOOKUP
         case pluckerSelectedWordEvent:
@@ -811,14 +805,19 @@ Boolean MainFormHandleEvent
                 FormType* mainForm;
                 WriteModeType  mode;
 
-                if ( event->data.frmUpdate.updateCode == frmUpdateAnchors )
+                if ( event->data.frmUpdate.updateCode == frmUpdateAnchors ) {
                     mode = WRITEMODE_LAYOUT_ANCHORS;
-                else
-                    mode = WRITEMODE_DRAW_CHAR;
+                }
+                else {
+                    mode                = WRITEMODE_DRAW_CHAR;
+                    forceMainFormUpdate = false;
+#ifdef HAVE_SILKSCREEN
+                    ResizeHandleFrmRedrawUpdateCode();
+#endif
+                }
 
                 mainForm = FrmGetFormPtr( GetMainFormId() );
                 if ( mode == WRITEMODE_DRAW_CHAR ) {
-                    FrmEraseForm( mainForm );
                     MainFormInit();
                     /* If we are just coming back from frmFullscreen,
                        don't reload GetHistoryCurrent().
@@ -853,29 +852,43 @@ Boolean MainFormHandleEvent
             }
             break;
 
+		case winDisplayChangedEvent:
+			handled = ResizeHandleWinDisplayChangedEvent();
+			break;
+
+		case winExitEvent:
+		    handled = ResizeHandleWinExitEvent();
+		    break;
+
         case winEnterEvent:
+#ifdef HAVE_SILKSCREEN
+            ResizeHandleWinEnterEvent();
+#endif
             if ( forceMainFormUpdate ) {
                 forceMainFormUpdate = false;
-                if ( ! MainFormWrong() )
-                    FrmUpdateForm( GetMainFormId(), frmRedrawUpdateCode );
+                if ( ! MainFormWrong() ) {
+                    EventType e;
+                    MemSet( &e, sizeof(EventType), 0 );
+                    e.eType                     = frmUpdateEvent;
+                    e.data.frmUpdate.formID     = GetMainFormId();
+                    e.data.frmUpdate.updateCode = frmRedrawUpdateCode;
+                    EvtAddUniqueEventToQueue( &e, 0, true );
+                }
             }
             handled = true;
             break;
 
-#ifdef HAVE_HANDERA_SDK
-        case displayExtentChangedEvent:
-              LineCacheClear();
-              SilkHandleChange();
-              break;
-#endif
-
         case frmOpenEvent:
         {
             UInt16 reference;
+#ifdef HAVE_SILKSCREEN
+            ResizeHandleFrmOpenEvent();
+#endif
             if ( MainFormWrong() ) {
                 handled = true;
                 break;
             }
+            forceMainFormUpdate = false;
             SetScreenMode();
             MainFormInit();
             LineCacheClear();
@@ -901,7 +914,7 @@ Boolean MainFormHandleEvent
         {
             MemHandle handle;
 
-            ResetSilkScreen();
+            HanderaResetSilkScreen();
 
             ReleaseFsTableHandle();
 
@@ -910,6 +923,10 @@ Boolean MainFormHandleEvent
             handle = GetCurrentRecord();
             FreeRecordHandle( &handle );
             ResetRecordReferences();
+            
+#ifdef HAVE_SILKSCREEN
+            ResizeHandleFrmCloseEvent();
+#endif
 
             handled = false;
             break;
