@@ -1,5 +1,5 @@
 /*
- * $Id: prefsform.c,v 1.68 2004/03/07 05:29:07 prussar Exp $
+ * $Id: prefsform.c,v 1.71 2004/04/29 01:52:05 prussar Exp $
  *
  * Viewer - a part of Plucker, the free off-line HTML viewer for PalmOS
  * Copyright (c) 1998-2002, Mark Ian Lillywhite and Michael Nordstrom
@@ -37,6 +37,7 @@
 #include "resourceids.h"
 #include "util.h"
 #include "os.h"
+#include "DIA.h"
 
 #include "prefsform.h"
 
@@ -160,7 +161,6 @@ static void PrefsFormInit( void )
 #endif
 
     prefsForm = FrmGetFormPtr( frmPrefs );
-    HanderaConvertForm( prefsForm );
 
 #ifdef HAVE_HANDSPRING_SDK
     if ( HaveHsNav() )
@@ -537,14 +537,32 @@ Boolean PrefsFormHandleEvent
             }
             break;
         }
+        
+        case winEnterEvent:
+			handled = ResizeHandleWinEnterEvent();
+			break;
+
+		case winDisplayChangedEvent:
+			handled = ResizeHandleWinDisplayChangedEvent();
+			break;
+
+		case winExitEvent:
+		    handled = ResizeHandleWinExitEvent();
+		    break;
 
         case frmOpenEvent:
+#ifdef HAVE_SILKSCREEN
+            ResizeHandleFrmOpenEvent();
+#endif
             PrefsFormInit();
             handled = true;
             break;
 
         case frmCloseEvent:
             PrefsReleaseSections();
+#ifdef HAVE_SILKSCREEN
+            ResizeHandleFrmCloseEvent();
+#endif
             handled = false;
             break;
 
