@@ -1,5 +1,5 @@
 /*
- * $Id: resourceids.h,v 1.135 2004/03/07 05:29:07 prussar Exp $
+ * $Id: resourceids.h,v 1.138 2004/04/24 17:25:12 prussar Exp $
  *
  * Viewer - a part of Plucker, the free off-line HTML viewer for PalmOS
  * Copyright (c) 1998-2002, Mark Ian Lillywhite and Michael Nordstrom
@@ -240,6 +240,7 @@
 #define frmMainBottomSonyLow    3013
 #define frmMainBottomSonyWide   3014
 #define frmMainSonyFull         3015
+#define frmMainDrawingArea      3016
 
 #define frmAbout                3100
 #define frmAboutOK              3101
@@ -485,7 +486,7 @@
 #define frmSyncDocList          3846
 #define frmOpenDocList          3847
 #define frmSortDoc              3848
-#define frmExportLink           3849
+/* #define frmExportLink           3849 */
 
 #define frmEmail                3900
 #define frmEmailTo              3901
@@ -727,6 +728,8 @@
 #define frmViewRecord           8005
 #define frmUpdateAnchors        8006
 
+#define resizeIndex             8500
+
 /* Armlets */
 #define armDoSearch             9000
 #define armRotateBitmap         9001
@@ -734,6 +737,8 @@
 
 /* Custom events */
 #define pluckerSelectedWordEvent  ( firstUserEvent + 0 )
+#define pluckerClosePopupEvent    ( firstUserEvent + 1 )
+#define pluckerDeleteFormEvent    ( firstUserEvent + 2 )
 
 /* Miscellaneous */
 #define MAX_BOOKMARK_LEN  100
