@@ -1,5 +1,5 @@
 /*
- * $Id: resultform.c,v 1.46 2004/03/20 11:57:49 nordstrom Exp $
+ * $Id: resultform.c,v 1.50 2004/04/29 01:52:05 prussar Exp $
  *
  * Viewer - a part of Plucker, the free off-line HTML viewer for PalmOS
  * Copyright (c) 1998-2002, Mark Ian Lillywhite and Michael Nordstrom
@@ -28,7 +28,7 @@
 #include "resourceids.h"
 #include "search.h"
 #include "util.h"
-#include "silkscreen.h"
+#include "DIA.h"
 #include "font.h"
 #include "hires.h"
 #include "grayfont.h"
@@ -267,8 +267,6 @@ static void ResultFormInit( void )
     HiResAdjust( &actualExtent, sonyHiRes | handeraHiRes );
     maxResult = actualExtent / FntLineHeight();
 
-    SonySilkDisableResize(); /* FIXME!  This is a temporary work-around. */
-
     GetSearchString( pattern );
 
     SysCopyStringResource( searching, strResultSearching );
@@ -282,7 +280,6 @@ static void ResultFormInit( void )
     fldPtr = GetObjectPtr( frmResultStatus );
     FldSetTextPtr( fldPtr, searching );
 
-    HanderaConvertForm( resultForm );
     FrmDrawForm( resultForm );
 
     ClearSearchResult();
@@ -358,14 +355,11 @@ static Boolean SearchResultHandleEvent
             startFromBeginning = false;
         }
         done = SearchDocument( pattern, startFromBeginning, &findMore,
-                   Prefs()->searchMode );\
+                   Prefs()->searchMode );
 
         startFromBeginning = false;
 
         if ( done ) {
-
-            SonySilkEnableResize(); /* FIXME!  Temporary work-around. */
-
             if ( findMore )
                 ShowCancelMore();
             else
@@ -420,7 +414,6 @@ Boolean ResultFormHandleEvent
                 break;
 
             FntSetFont( initialFontStyle );
-            SonySilkEnableResize();
             FrmReturnToForm( GetMainFormId() );
             FrmUpdateForm( GetMainFormId(), frmRedrawUpdateCode );
             handled = true;
@@ -485,8 +478,6 @@ Boolean ResultFormHandleEvent
                     match.data.frmGoto.matchCustom      = 0;
 
                     EvtAddEventToQueue( &match );
-                    SonySilkEnableResize(); /* FIXME!  Temporary work-around. */
-
                 }
                 SndPlaySystemSound( sndClick );
                 handled = true;
@@ -494,7 +485,22 @@ Boolean ResultFormHandleEvent
             break;
         }
 
+        case winEnterEvent:
+			handled = ResizeHandleWinEnterEvent();
+			break;
+
+		case winDisplayChangedEvent:
+			handled = ResizeHandleWinDisplayChangedEvent();
+			break;
+
+		case winExitEvent:
+		    handled = ResizeHandleWinExitEvent();
+		    break;
+
         case frmOpenEvent:
+#ifdef HAVE_SILKSCREEN
+            ResizeHandleFrmOpenEvent();
+#endif
 #ifdef HAVE_GRAY_FONT
             oldOrientation = GrayFntSetOrientation( GRAY_FONT_NORMAL );
 #endif
@@ -507,7 +513,9 @@ Boolean ResultFormHandleEvent
             GrayFntSetOrientation( oldOrientation );
 #endif
             FntSetFont( initialFontStyle );
-            SonySilkEnableResize();
+#ifdef HAVE_SILKSCREEN
+            ResizeHandleFrmCloseEvent();
+#endif            
             handled = false;
             break;
 
