@@ -1,5 +1,5 @@
 /*
- * $Id: screen.c,v 1.46 2004/03/20 01:57:30 prussar Exp $
+ * $Id: screen.c,v 1.47 2004/04/18 15:34:48 prussar Exp $
  *
  * Viewer - a part of Plucker, the free off-line HTML viewer for PalmOS
  * Copyright (c) 1998-2002, Mark Ian Lillywhite and Michael Nordstrom
@@ -29,8 +29,8 @@
 #include "os.h"
 #include "prefsdata.h"
 #include "resourceids.h"
-#include "silkscreen.h"
 #include "palmbitmap.h"
+#include "handera.h"
 
 #include "screen.h"
 
@@ -175,7 +175,7 @@ void SetScreenModeOS3( void )
     }
 
     if ( depthChanged ) {
-        ResetSilkScreen();
+        HanderaResetSilkScreen();
         ResetCache();
     }
     SetFontFunctions();
