@@ -1,5 +1,5 @@
 /*
- * $Id: table.c,v 1.62 2004/03/09 22:17:03 chrish Exp $
+ * $Id: table.c,v 1.63 2004/03/24 21:33:08 chrish Exp $
  *
  * Viewer - a part of Plucker, the free off-line HTML viewer for PalmOS
  * Copyright (c) 1998-2002, Mark Ian Lillywhite and Michael Nordstrom
@@ -168,7 +168,6 @@ static Coord DoAlign( Int8 align, Coord width, Coord size ) TABLE_SECTION;
  ***********************************************************************/
 static WinHandle        osWindow;
 static UInt16           depth;
-static UInt16           oldDepth;
 static Boolean          isLargeTable = false;
 static TextContext      text_color;
 static TextContext      border_color;
@@ -688,7 +687,6 @@ Boolean GetTableSize
     Boolean     result;
     UInt32      size;
     Cell*       cells;
-    UInt32      tableDepth;
 
 
     tableHandle = GetRecordHandle( reference );
@@ -732,7 +730,6 @@ Boolean GetTableSize
     } ErrEndCatch
 
     MemSet( cells, size, 0 );
-    tableDepth = table->depth;
 
     result = GetTableMetrics( table, cells, tableWidth, tableHeight );
 
@@ -785,7 +782,7 @@ static Boolean GetTableMetrics
     } ErrEndCatch
 
 
-    depth = table->depth;
+    depth = min( table->depth, Prefs()->screenDepth );
 
     /* Set defaults */
     for ( row = 0; row < table->rows; row++ ) {
@@ -1225,11 +1222,6 @@ Boolean LoadTable
         SafeMemPtrFree( cells );
         return false;
     }
-    if ( Prefs()->screenDepth != depth ) {
-        oldDepth = Prefs()->screenDepth;
-        Prefs()->screenDepth = depth;
-        SetScreenMode();
-    }
 
     dynamicUid      = record->uid * 100;
     dynamicUid      = -dynamicUid;
@@ -1426,12 +1418,6 @@ Error:
         }
     }
 
-    if ( oldDepth != 0 ) {
-        Prefs()->screenDepth = oldDepth;
-        SetScreenMode();
-        oldDepth = 0;
-    }
-
     ReleaseMultiList( list );
     ListRelease( tableAnchorList );
     AnchorListRelease();
@@ -1591,12 +1577,6 @@ void ReleaseFsTableHandle( void )
         fsTableHandle = NULL;
     }
 
-    if ( oldDepth != 0 ) {
-        Prefs()->screenDepth = oldDepth;
-        SetScreenMode();
-        oldDepth = 0;
-    }
-
     isLargeTable = false;
 }
 
