@@ -1,5 +1,5 @@
 /*
- * $Id: viewer.c,v 1.131 2004/03/20 12:26:15 nordstrom Exp $
+ * $Id: viewer.c,v 1.134 2004/04/24 17:25:12 prussar Exp $
  *
  * Viewer - a part of Plucker, the free off-line HTML viewer for PalmOS
  * Copyright (c) 1998-2002, Mark Ian Lillywhite and Michael Nordstrom
@@ -40,7 +40,7 @@
 #include "screen.h"
 #include "search.h"
 #include "session.h"
-#include "silkscreen.h"
+#include "DIA.h"
 #include "timeout.h"
 #include "uncompress.h"
 #include "util.h"
@@ -53,6 +53,7 @@
 #include "keyboardform.h"
 #include "grayfont.h"
 #include "xlit.h"
+#include "statusform.h"
 
 #include "viewer.h"
 
@@ -114,8 +115,6 @@ static EventHandler ListOfEventHandlers[] = {
     { frmMainTopHandera, MainFormHandleEvent },
     { frmMainBottomHandera, MainFormHandleEvent },
     { frmMainBottomHanderaLow, MainFormHandleEvent },
-    { frmMainBottomSonyLow, MainFormHandleEvent },
-    { frmMainBottomSonyWide, MainFormHandleEvent },
     { frmMainNoneHandera, MainFormHandleEvent },
     { frmFont, FontFormHandleEvent },
     { frmFontOS2, FontFormHandleEvent },
@@ -123,15 +122,17 @@ static EventHandler ListOfEventHandlers[] = {
     { frmKeyboard, KeyboardFormHandleEvent },
     { frmPrefs, PrefsFormHandleEvent },
     { frmLibrary, LibraryFormHandleEvent },
+    { frmOpenDocList, StatusFormHandleEvent },
+    { frmSyncDocList, StatusFormHandleEvent },
+    { frmSortDoc, StatusFormHandleEvent },
+    { frmAbout, StatusFormHandleEvent },
     { frmLibraryHandera, LibraryFormHandleEvent },
     { frmLibraryHanderaLow, LibraryFormHandleEvent },
-    { frmLibrarySonyWide, LibraryFormHandleEvent },
     { frmDetails, DetailsFormHandleEvent },
     { frmHardcopy, HardcopyFormHandleEvent },
     { frmEmail, EmailFormHandleEvent },
     { frmSearch, SearchFormHandleEvent },
     { frmResult, ResultFormHandleEvent },
-    { frmResultSonySilkMin, ResultFormHandleEvent },
     { frmAddBookmark, AddBookmarkFormHandleEvent },
     { frmBookmarks, BookmarksFormHandleEvent },
     { frmRenameDoc, RenameDocFormHandleEvent },
@@ -153,7 +154,7 @@ static Err StartApplication
 {
     volatile UInt16 formId;
     Err             err;
-    
+
 
     OS_Init();
 
@@ -182,11 +183,8 @@ static Err StartApplication
     SetScreenMode();
     SetFontFunctions();
 
-    /* Restore the silkscreen to the last-used position */
-    if ( Prefs()->hideSonyStatusBar ) {
-        Prefs()->previousSilkStatus = SILKSCREEN_NONE;
-    }
-    SetSilkScreenStatus( Prefs()->previousSilkStatus );
+    InitializeResizeSupport( resizeIndex );
+    LoadResizePrefs( ( UInt32 )ViewerAppID, ( UInt16 )ViewerPrefDIA );
 
     if ( cmdPBP != NULL ) {
         Char    name[ dmDBNameLength ];
@@ -202,22 +200,13 @@ static Err StartApplication
             NULL, NULL, NULL, &type, &creator );
 
         if ( creator == ViewerAppID && type == ViewerDocumentType ) {
-            FormType* frm;
-
-            if ( Prefs()->syncPolicy == SYNC_MANUAL )
-                frm = FrmInitForm( frmOpenDocList );
-            else
-                frm = FrmInitForm( frmSyncDocList );
-
-            FrmSetActiveForm( frm );
-            FrmDrawForm( frm );
+            ShowSyncMessage( NO_POPUP );
 
             StrCopy( Prefs()->docName, name );
             Prefs()->lastForm = GetMainFormId();
             InitializeDocInfoList();
 
-            FrmEraseForm( frm );
-            FrmDeleteForm( frm );
+            HideMessage( NO_POPUP );
         }
     }
 
@@ -279,12 +268,6 @@ static void EnableNotification
                 SysNotifyRegister( cardNo, dbID, sysNotifyVolumeUnmountedEvent,
                                    NULL, sysNotifyNormalPriority, 0 );
             }
-            if ( SilkScreenType() == sonyV1SilkScreen ||
-                 SilkScreenType() == sonyV2SilkScreen ||
-                 SilkScreenType() == sonyV3SilkScreen ) {
-                SysNotifyRegister( cardNo, dbID, sysNotifyDisplayChangeEvent,
-                                   NULL, sysNotifyNormalPriority, 0 );
-            }
         } else {
 #ifdef HAVE_SONY_SDK
             if ( IsSony() ) {
@@ -300,12 +283,6 @@ static void EnableNotification
                                      sysNotifyVolumeUnmountedEvent,
                                      sysNotifyNormalPriority );
             }
-            if ( SilkScreenType() == sonyV1SilkScreen ||
-                 SilkScreenType() == sonyV2SilkScreen ||
-                 SilkScreenType() == sonyV3SilkScreen ) {
-                SysNotifyUnregister( cardNo, dbID, sysNotifyDisplayChangeEvent,
-                                     sysNotifyNormalPriority );
-            }
         }
     }
 }
@@ -319,6 +296,8 @@ static void HandleNotification
     SysNotifyParamType* cmdPBP   /* pointer to command parameter block */
     )
 {
+    if ( HandleResizeNotification( cmdPBP->notifyType ) )
+        return;
     switch ( cmdPBP->notifyType ) {
 #ifdef HAVE_SONY_SDK
         case sonySysNotifyHoldStatusChangeEvent:
@@ -338,10 +317,6 @@ static void HandleNotification
             cmdPBP->handled |= vfsHandledStartPrc;
             break;
 
-        case sysNotifyDisplayChangeEvent:
-            SilkVerifyChange();
-            break;
-
         default:
             break;
     }
@@ -570,6 +545,7 @@ static void HandleFormLoad
 
         for ( list = ListOfEventHandlers; list->formID != 0; list++ ) {
             if ( list->formID == formID ) {
+                SetResizePolicy( formID );
                 FrmSetEventHandler( form, list->handler );
                 return;
             }
@@ -705,7 +681,6 @@ static void StopApplication( void )
 
     /* Save in the prefs what our silkscreen is set to, so its status is
        restored whenever plucker's loaded again */
-    Prefs()->previousSilkStatus = GetSilkScreenStatus();
 
     FrmSaveAllForms();
     FrmCloseAllForms();
@@ -718,6 +693,9 @@ static void StopApplication( void )
     ReleaseSearchQueue();
     DeleteUncompressBuffer();
     WritePrefs();
+    SaveResizePrefs( ( UInt32 )ViewerAppID, ( UInt16 )ViewerPrefDIA,
+        ( Int16 )ViewerVersion );
+    TerminateResizeSupport();
     CloseKeyboardMap();
     AnchorListRelease();
     ReleaseActionList();
